@@ -1,7 +1,7 @@
 import typing as t
 from dataclasses import dataclass
 
-from pydantic import BaseModel, Field
+from pydantic import BaseModel, ConfigDict, Field
 
 from dreadnode.types import AnyDict
 
@@ -31,6 +31,8 @@ class ObjectUri(BaseModel):
 
 
 class ObjectVal(BaseModel):
+    model_config = ConfigDict(serialize_by_alias=True)
+
     hash: str
     schema_hash: str
     value_: t.Any = Field(alias="value")
