@@ -505,87 +505,3 @@ class Task(t.Generic[P, R]):
         """
         spans = await self.try_map_run(count, *args, **kwargs)
         return [span.output for span in spans if span]
-
-
-class TaskInputWarning(UserWarning):
-    pass
-
-
-CastT = t.TypeVar("CastT")
-
-
-class TaskInput:
-    """
-    A placeholder to dynamically retrieve an input from the active TaskSpan.
-    """
-
-    def __init__(self, name: str, *, process: t.Callable[[t.Any], t.Any] | None = None) -> None:
-        """
-        Args:
-            name: The name of the input to retrieve, as logged via `task.log_input(name=...)`.
-            process: An optional function to process the input value before returning it.
-                This can be used to transform or extract from the raw input value.
-        """
-        self.name = name
-        self.process = process
-
-    def __repr__(self) -> str:
-        return f"TaskInput(name='{self.name}')"
-
-    @t.overload
-    def resolve(self, *, cast_as: None = None) -> t.Any: ...
-
-    @t.overload
-    def resolve(self, *, cast_as: type[CastT]) -> CastT: ...
-
-    def resolve(self, *, cast_as: type[CastT] | None = None) -> t.Any:  # noqa: PLR0911
-        """
-        Resolve the input from the current TaskSpan.
-
-        Args:
-            cast_as: Optionally cast the resolved value to a specific type.
-
-        Returns:
-            The value of the input from the current TaskSpan.
-        """
-        from dreadnode.tracing.span import current_task_span
-
-        if (task := current_task_span.get()) is None:
-            warn_at_user_stacklevel(
-                "TaskInput.resolve() called outside of an active TaskSpan context. "
-                "This will raise an error in future versions.",
-                TaskInputWarning,
-            )
-            return None
-
-        try:
-            task_input = task.inputs[self.name].value
-        except KeyError:
-            warn_at_user_stacklevel(
-                f"Input '{self.name}' not found in the active TaskSpan. "
-                f"Available inputs are: {list(task.inputs.keys())}",
-                TaskInputWarning,
-            )
-            return None
-
-        try:
-            if self.process is not None:
-                return self.process(task_input)
-        except Exception as e:  # noqa: BLE001
-            warn_at_user_stacklevel(
-                f"Error processing TaskInput '{self.name}': {e}",
-                TaskInputWarning,
-            )
-            return task_input
-
-        if cast_as is not None:
-            try:
-                return cast_as(task_input)  # type: ignore [call-arg]
-            except Exception as e:  # noqa: BLE001
-                warn_at_user_stacklevel(
-                    f"Error casting TaskInput '{self.name}' to {cast_as.__name__}: {e}",
-                    TaskInputWarning,
-                )
-                return task_input
-
-        return task_input
